@@ -120,7 +120,7 @@ class Node:
         self._version: Version | None = None
         self._api_version: int | None = None
         self._manager = manager
-        self._session = aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=30), json_serialize=ujson.dumps)
+        self._session = aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=120), json_serialize=ujson.dumps)
         self._temporary = temporary
         if not temporary:
             # noinspection PyProtectedMember
@@ -196,14 +196,15 @@ class Node:
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
+            if self.websocket and self.websocket._connecting is True:
+                return
+
             try:
                 await self.websocket.ping()
-                await self.fetch_version(raise_on_error=True)
                 self._logger.trace("Healthy")
             except Exception:  # noqa
                 # noinspection PyProtectedMember
                 if self.websocket._connecting is True:
-                    self._logger.debug("Already connecting - skipping reconnect on unhealthy")
                     return
                 self._logger.warning("Unhealthy - Triggering a state reset")
                 await self._unhealthy()
@@ -214,7 +215,6 @@ class Node:
             if (self.down_votes / playing_players) >= 0.5:
                 # noinspection PyProtectedMember
                 if self.websocket._connecting is True:
-                    self._logger.debug("Already connecting - skipping reconnect on unhealthy")
                     return
                 await self._unhealthy()
 
@@ -940,14 +940,14 @@ class Node:
                 tracks = (
                     [
                         t.to_dict()
-                        for t in await self.node_manager.client.decode_tracks(
-                            [tracks[0]] if first else tracks, raise_on_failure=False
-                        )
+                        for t in await self.node_manager.client.decode_tracks(tracks, raise_on_failure=False)
                         if isinstance(t, Track)
                     ]
                     if tracks
                     else []
                 )
+                if tracks and first:
+                    tracks = [tracks[0]]
             except Exception:  # noqa
                 tracks = []
                 load_type = "LOAD_FAILED"
